.. -*- coding: utf-8 -*-

############################
  aiotk -- asyncio toolkit
############################

Purpose
=======

This is a collection of asyncio-related utilities that I have found useful,
that I've used in at least two projects and that seem like they might be useful
to others.

Contributing
============

We welcome pull requests!

License
=======

Licensed under the very permissive MIT license for maximum usage.
